pub struct Convergence {
pub likelihood: f64,
pub pyl: f64,
pub eps: f64,
}Expand description
This struct contains the convergence criteria for the algorithm
Fields
likelihood: f64The objective function convergence criterion for the algorithm
The objective function is the negative log likelihood Previously referred to as THETA_G
pyl: f64The PYL convergence criterion for the algorithm
P(Y|L) represents the probability of the observation given its weighted support Previously referred to as THETA_F
eps: f64Precision convergence criterion for the algorithm
The precision variable, sometimes referred to as eps, is the distance from existing points in the grid to the candidate point. A candidate point is suggested at a distance of eps times the range of the parameter.
For example, if the parameter alpha has a range of [0.0, 1.0], and eps is 0.1, then the candidate point will be at a distance of 0.1 * (1.0 - 0.0) = 0.1 from the existing grid point(s).
Previously referred to as THETA_E